# django-mistune

[![PyPI - Version](https://img.shields.io/pypi/v/django-mistune.svg)](https://pypi.org/project/django-mistune)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-mistune.svg)](https://pypi.org/project/django-mistune)

Simple yet customizable Django template filter to render Markdown using the
awesome [Mistune](https://mistune.readthedocs.io/en/latest/) package.

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install django-mistune
```

## License

`django-mistune` is distributed under the terms of the
[MIT](https://spdx.org/licenses/MIT.html) license.
